@@ -12,7 +12,7 @@ from deepdriver.sdk.data_types.run import get_run
 from deepdriver.sdk.data_types.table import Table
 from deepdriver.sdk.interface import interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import ArtifactEntry as grpc_ArtifactEntry
-
+import json
 
 class ArtifactEntry:
 
@@ -115,7 +115,19 @@ class Artifacts:
             if artifact_entry.type == "TABLE":
                 return Table.from_file(artifact_entry.local_path)
             if artifact_entry.type == "IMAGE":
-                return Image(artifact_entry.local_path)
+                #metadata를 가지고 있는 json 파일  read(cpation, boxes 정보)
+                json_file_name = os.path.splitext(artifact_entry.local_path)[0] + ".json"
+                if os.path.exists(json_file_name):
+                    with open(json_file_name, "r") as f:
+                        metadata = json.load(f)
+                        boxes = metadata['boxes'] if 'boxes' in metadata and metadata['boxes'] else None
+                        if boxes:
+                            boxes = {"predictions": boxes}
+                        caption = metadata['caption'] if 'caption' in metadata and metadata['caption'] else None
+
+                        return Image(artifact_entry.local_path, boxes=boxes, caption=caption)
+                else:
+                    return Image(artifact_entry.local_path)
             if artifact_entry.type == "CHART":
                 return Chart.from_file(artifact_entry.local_path)
         else:
@@ -154,11 +166,13 @@ class Artifacts:
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name))
 
+
             json_file_path = os.path.join(".", data.get_path(name))
             json_digest, json_size = data.file_dump(json_file_path, name)
+
             self.entry_list.append(
                 ArtifactEntry(path=data.get_path_json(name), local_path=json_file_path, size=size, digest=json_digest, status="ADD",
-                              lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name))
+                              lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name+"_json"))
 
         elif isinstance(data, Chart):
             assert_that(name).is_not_none()
@@ -182,10 +196,11 @@ class Artifacts:
 
                     json_file_path = os.path.join(".", n.get_path(name))
                     json_digest, json_size = n.file_dump(json_file_path, name)
+
                     self.entry_list.append(
                         ArtifactEntry(path=n.get_path_json(name), local_path=json_file_path, size=size,
                                       digest=json_digest, status="ADD",
-                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(name), key=name))
+                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(json_file_key), key=name+"_json"))
 
 
     def __add_file(self, data: Union[str], name: str = None, depth: int = 0) -> None:
