@@ -80,6 +80,18 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
 
         hpo_config['parameters'] = key_value_parameters_list
 
+    if hpo_config and 'env' in hpo_config:
+        env_dict = hpo_config['env']
+        key_value_parameters_list = []
+        for key, value in env_dict.items():
+            key_value_dict = {
+                "key": key,
+                "value": value
+            }
+            key_value_parameters_list.append(key_value_dict)
+        hpo_config['env'] = key_value_parameters_list
+
+
     rsp = interface.create_hpo(exp_name, team_name, hpo_config)
     logger.info("HPO initialized\n"
                 f"Team Name={rsp['teamName']}\n"
